import { Button, Form, Input, Select, Space, Table } from "antd";
import { useAssessmentStandardContext } from "./assessment-standard-provider";
import toast from "react-hot-toast";
import { api, useSport } from "@nice/client";
import { useEffect, useMemo } from "react";
export default function StandardCreateContent() {
    const {form,sportProjectList,ageRanges,records,showAgeModal,showScoreModal,setRecords,setAgeRanges,isStandardCreate,setIsStandardCreate} = useAssessmentStandardContext();
    const { createSportStandard,updateSportStandard } = useSport();
    const projectId = Form.useWatch('projectId', form);
    const gender = Form.useWatch('gender', form);
    const personType = Form.useWatch('personType', form);
    const transformedObject = useMemo(()=>{
        return records.reduce((acc, current) => {
            const scoreKey = current.score.toString(); // 将 score 转换为字符串作为键
            if (acc[scoreKey]) {
                // 如果键已存在，将当前 standard 数组合并到已有的数组中
                acc[scoreKey] = acc[scoreKey].concat(current.standards);
            } else {
                // 如果键不存在，创建一个新的数组
                acc[scoreKey] = current.standards;
            }
            return acc;
        }, {});
    },[records])
    const columns = [
        {
            title: '分数',
            dataIndex: 'score',
            key: 'score',
            width: 100,
        },
        ...ageRanges.map((range, index) => ({
            title: range.label,
            dataIndex: `standard[${index}]`,
            key: `standard[${index}]`,
            render: (_: any, record: any) => (
                <Input
                    style={{ width: '80px' }}
                    value={record.standards[index]}
                    onChange={(e) => {
                        const inputValue = e.target.value;
                        const numericValue = inputValue ? Number(inputValue) : null;
                        handleStandardChange(record.score, index, numericValue);
                    }}
                />
            ),
        })),
    ];
    // 处理标准值变化
    const handleStandardChange = (score: number, ageIndex: number, value: number | null) => {
        const updatedRecords = records.map(record => {
            if (record.score === score) {
                const updatedStandards = [...record.standards];
                updatedStandards[ageIndex] = value;
                return { ...record, standards: updatedStandards };
            }
            return record;
        });
        setRecords(updatedRecords);
    };
    const handleSave = async () => {
        // 转换为新格式
        if(isStandardCreate){
            await createStandard()
        }else{
            await updateStandard()
        }
    }
    const createStandard = async ()=>{
        const result = await createSportStandard.mutateAsync({
            data: {
                projectId: form.getFieldsValue().projectId,
                gender: form.getFieldsValue().gender,
                personType: form.getFieldsValue().personType,
                ageRanges: ageRanges,
                scoreTable: transformedObject
            }
        } as any)
        console.log(result)
        toast.success("保存标准成功")
    }
    const updateStandard = async ()=>{
        const result = await updateSportStandard.mutateAsync({
            data: {
                id: data[0].id,
                ageRanges: ageRanges,
                scoreTable: transformedObject
            }
        } as any)
        console.log(result)
        toast.success("更新标准成功")
    }
    const { data, isLoading } = api.sportStandard.findMany.useQuery({
        where: {
            projectId: projectId || "", // 空值处理
            gender: gender ?? undefined,
            personType: personType || ""
        }
    }, {
        enabled: !!projectId && gender !== undefined && !!personType // 查询启用条件
    });
    useEffect(() => {
        if (data && data.length) {
            setIsStandardCreate(false)
            const records: {
                score: number;
                standards: number[];
            }[] = Object.entries(JSON.parse(String(data[0].scoreTable))).map(([score, standards]) => ({ 
                score: Number(score),
                standards: standards as number[]
            }));
            setAgeRanges(JSON.parse(String(data[0].ageRanges)))
            setRecords(records)
        }
    }, [data])

    return (
        <Form form={form} layout="vertical">

            <Space size="large" className="my-6">
                <Form.Item label="项目" name="projectId">
                    <Select
                        style={{ width: 200 }}
                        placeholder="选择考核项目"
                        options={sportProjectList?.filter(item=>item.deletedAt === null)?.map((item) => ({ value: item.id, label: `${item.name}（${item.unit}）` })) || []}
                    />
                </Form.Item>

                <Form.Item label="性别" name="gender">
                    <Select
                        style={{ width: 120 }}
                        placeholder="选择性别"
                        options={[
                            { value: true, label: '男' },
                            { value: false, label: '女' },
                        ]}
                    />
                </Form.Item>

                <Form.Item label="人员类型" name="personType">
                    <Select
                        style={{ width: 160 }}
                        placeholder="选择人员类型"
                        options={[
                            { value: 'OFFICER', label: '警员' },
                            { value: 'STAFF', label: '职工' },
                        ]}
                    />
                </Form.Item>
                <Button onClick={showAgeModal} className="mt-9">添加年龄范围</Button>
                <Button onClick={showScoreModal} className="mt-9 ml-2">添加分数与对应标准</Button>
                <Button type="primary" onClick={handleSave} className='mt-9 ml-2'>保存标准</Button>
            </Space>

            <Table
                columns={columns}
                dataSource={records}
                bordered
                pagination={false}
                scroll={{ x: 'max-content' }}
            />
        </Form>
    )
}