import { Button, Table, Modal, Form, Upload, Skeleton } from "antd";
import { useEffect, useState,} from "react";
import toast from "react-hot-toast";
import _ from "lodash";
import * as XLSX from 'xlsx';
import { UploadOutlined, DownloadOutlined } from '@ant-design/icons';
import { useSportPageContext } from "./sportPageProvider";
import SportPageModal from "./sportPageModal";
import { api, useTrainSituation } from "@nice/client";

export default function SportPage() {
    const [sportsData, setSportsData] = useState([]);
    const { sportProjectList, handlNewScoreOpen, staffsWithScore, staffsWithScoreLoading } = useSportPageContext()
    const {deleteSameGroupTrainSituation} = useTrainSituation()
    useEffect(() => {
        if (!staffsWithScore) return;
        const newSportsData = []
        staffsWithScore.forEach(item => {
            const groupedTrainSituations = {};
            item.trainSituations.forEach(train => {
                if(train.groupId === null) return
                const groupId = train.groupId;
                if (!groupedTrainSituations[groupId]) {
                    groupedTrainSituations[groupId] = {
                        totalScore: 0,
                        trainScore: {},
                        situations: []
                    };
                }
                groupedTrainSituations[groupId].totalScore += train.score;
                groupedTrainSituations[groupId].trainScore[train.trainContent.title] = `${train.score}分（${train.value}）`;
                groupedTrainSituations[groupId].situations.push(train);
                console.log(groupedTrainSituations[groupId])
                newSportsData.push({
                    id: item.id,
                    name: item.username,
                    gender: item.sex ? "男" : "女",
                    bodyType: "标准",
                    age: item.age,
                    unit: item.department?.name,
                    situationIds: groupedTrainSituations[groupId].situations.map(train => train.id),
                    totalScore:groupedTrainSituations[groupId].totalScore,
                    ...groupedTrainSituations[groupId].trainScore,
                    groupId
                })
            });
            
        });
        console.log(newSportsData)
        setSportsData(newSportsData);
    }, [staffsWithScore])
    const columns = [
        {
            title: "姓名",
            dataIndex: "name",
            key: "name",
        },
        {
            title: "性别",
            dataIndex: "gender",
            key: "gender",
        },
        {
            title: "年龄",
            dataIndex: "age",
            key: "age",
        },
        {
            title: "单位",
            dataIndex: "unit",
            key: "unit",
        },
        ...sportProjectList?.filter(item=>item.deletedAt === null).map((item) => ({
            title: item.name,
            dataIndex: item.name,
            key: item.name,
            editable: true,
        })),
        {
            title: "BMI",
            dataIndex: "bodyType",
            key: "bodyType",
            editable: true,
        },
        {
            title: "总成绩",
            dataIndex: "totalScore",
            key: "totalScore",
            editable: true,
        },

        {
            title: "操作",
            key: "action",
            render: (_, record) => (
                <div className="flex space-x-2">
                    <Button type="primary" key={record.groupId} onClick={() => handleEdit(record)}>编辑</Button>
                    <Button danger onClick={() => handleDelete(record)}>删除</Button>
                </div>
            ),
        }
    ];
    const handleEdit = (record) => {

    };
    const handleDelete = (record) => {
        Modal.confirm({
            title: '确认删除',
            content: '确定要删除该记录吗？',
            okText: '确定',
            cancelText: '取消',
            onOk: async () => {
                try {
                    // 模拟删除操作
                    console.log(record)
                    await deleteSameGroupTrainSituation.mutateAsync(
                        {
                            groupId:record.groupId
                        }
                    )
                    toast.success("删除成功");
                } catch (error) {
                    console.error('删除记录时出错:', error);
                    toast.error("删除失败");
                }
            }
        });
    };
    // 导出成绩为Excel
    const handleExport = () => {
        // 创建工作簿
        const wb = XLSX.utils.book_new();

        // 准备导出数据（移除id字段）
        const exportData = sportsData.map(({ id, ...rest }) => rest);

        // 转换为工作表
        const ws = XLSX.utils.json_to_sheet(exportData);

        // 将工作表添加到工作簿
        XLSX.utils.book_append_sheet(wb, ws, "成绩数据");

        // 生成Excel文件并下载
        XLSX.writeFile(wb, "体育成绩表.xlsx");

        toast.success("成绩导出成功");
    };

    // 导入成绩
    const handleImport = (file) => {
        const reader = new FileReader();

        reader.onload = (e) => {
            try {
                const data = new Uint8Array(e.target.result);
                const workbook = XLSX.read(data, { type: 'array' });
                // 获取第一个工作表
                const worksheet = workbook.Sheets[workbook.SheetNames[0]];
                // 转换为JSON
                const jsonData = XLSX.utils.sheet_to_json(worksheet);
                // 添加id字段
                const importedData = jsonData.map((item, index) => ({
                    id: sportsData.length + index + 1,
                    ...item,
                    // 确保totalScore是计算所有项目成绩的和
                    totalScore: calculateTotalScore(item)
                }));

                // 更新数据
                setSportsData([...sportsData, ...importedData]);
                toast.success(`成功导入${importedData.length}条记录`);
            } catch (error) {
                console.error('导入失败:', error);
                toast.error("导入失败，请检查文件格式");
            }
        };

        reader.readAsArrayBuffer(file);

        // 防止自动上传
        return false;
    };

    return (
        <div className="p-2 min-h-screen bg-gradient-to-br">
            {/* {JSON.stringify(staffsWithScore)} */}
            <Form>
                <div className="p-4 h-full flex flex-col">
                    <div className="max-w-full mx-auto flex-1 flex flex-col">
                        <div className="flex justify-between mb-4 space-x-4 items-center">
                            <div className="text-2xl">成绩总览</div>
                            <div className="flex space-x-2">
                                <Upload
                                    beforeUpload={handleImport}
                                    showUploadList={false}
                                    accept=".xlsx,.xls"
                                >
                                    <Button icon={<UploadOutlined />}>导入成绩</Button>
                                </Upload>
                                <Button
                                    icon={<DownloadOutlined />}
                                    onClick={handleExport}
                                >
                                    导出成绩
                                </Button>
                                <Button
                                    type="primary"
                                    onClick={handlNewScoreOpen}
                                    className="font-bold py-2 px-4 rounded"
                                >
                                    新建成绩
                                </Button>
                            </div>
                        </div>

                        {staffsWithScoreLoading ? (
                            <Skeleton></Skeleton>
                        ) : (
                            <Table
                                rowClassName={() => 'editable-row'}
                                columns={columns}
                                dataSource={sportsData}
                                tableLayout="fixed"
                                rowKey="id"
                                pagination={{
                                    position: ["bottomCenter"],
                                    className: "flex justify-center mt-4",
                                    pageSize: 10,
                                }}
                            />
                        )}
                    </div>
                </div>
            </Form>
            <SportPageModal />
        </div>
    );
}